hoppet benchmarking/ directory
==============================

- [evolution_n3lo_tests.f90](evolution_n3lo_tests.f90): for testing the
  N3LO evolution, including the scale variation 

- [prec_and_timing.f90](prec_and_timing.f90): for testing precision and
  timing

- [structure_functions_benchmark_checks.f90](structure_functions_benchmark_checks.f90): 
  for structure functions benchmarks as in [arXiv:2404.15711](https://arxiv.org/abs/2404.15711)

- [benchmark.f90](benchmark.f90): used for the benchmarks in [hep-ph/0511119](https://arxiv.org/abs/hep-ph/0511119)

- [compare2files_v2.f90](compare2files_v2.f90): used for comparing the output from two 
  runs of `prec_and_timing`